@@ -5,14 +5,16 @@ from __future__ import annotations
 
 import os
 import sys
+from concurrent.futures import ThreadPoolExecutor
 
 import click
 import pandas as pd
 
 sys.path.append(os.path.dirname(os.path.dirname(os.path.abspath(__file__))))
+from imdb_rating_classifier import __version__  # noqa: E402
 from imdb_rating_classifier.penalizer import penalize_reviews  # noqa: E402
-from imdb_rating_classifier.schema import MovieChart, validate  # noqa: E402
-from imdb_rating_classifier.scraper import Scraper, logger  # noqa: E402
+from imdb_rating_classifier.schema import MovieChart, normalize  # noqa: E402
+from imdb_rating_classifier.scraper import Scraper, get_movie_oscar_data, logger  # noqa: E402
 
 # help context
 CONTEXT_SETTINGS = dict(help_option_names=['-h', '--help'])
@@ -25,6 +27,7 @@ BASE_DIR = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
     context_settings=CONTEXT_SETTINGS,
     help='Application entry point for IMDB rating classifier.',
 )
+@click.version_option(version=__version__, prog_name='IMDB Rating Classifier')
 @click.pass_context
 def main(ctx: click.Context) -> None:
     """
@@ -64,18 +67,30 @@ def generate(output: str, number_of_movies: int) -> None:
     )
     movies = scraper.scrape()
 
+    # get the oscars winners data
+    logger.info('Getting the Oscar winners data...')
+    # speed up the process
+    with ThreadPoolExecutor(max_workers=10) as executor:
+        results = executor.map(get_movie_oscar_data, [movie['url'] for movie in movies])
+    # add the oscars data to the movies
+    for movie, result in zip(movies, results):
+        movie['oscars_won'] = result
+
     # convert the original set of movies to dataframe
     logger.info('Converting to original set of movies to a dataframe...')
     raw_input_df = pd.DataFrame(movies)
-    refined_df = validate(raw_input_df)
+
+    # normalize the dataframe
+    logger.info('Normalizing the dataframe...')
+    refined_df = normalize(raw_input_df)
 
     # recreate the movies dict from the dataframe
-    movies = refined_df.to_dict(orient='records')
+    movies_dict = refined_df.to_dict(orient='records')
 
     # validate the movies
     logger.info('Validating the movies...')
     try:
-        valid_movies = [MovieChart(**movie) for movie in movies]
+        valid_movies = [MovieChart(**movie) for movie in movies_dict]
     except Exception as e:
         logger.error(e)
         raise
@@ -83,7 +98,7 @@ def generate(output: str, number_of_movies: int) -> None:
 
     # penalize the movies based on the ruleset defined in the penalizer module
     logger.info('Penalizing movies...')
-    penalized_movies = penalize_reviews(movies)
+    penalized_movies = penalize_reviews(movies_dict)
     # check the number of penalized movies
     number_of_penalized_movies = len(
         [movie for movie in penalized_movies if 'penalized' in movie and movie['penalized'] is True],
